:orphan:

General
-------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Create a simple histogram of the PMT signals (ToTs) in all events. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_tot_histogram_thumb.png

        :ref:`sphx_glr_auto_examples_plot_tot_histogram.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_tot_histogram

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Sparse Cone ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_sparsecone_thumb.png

        :ref:`sphx_glr_auto_examples_plot_sparsecone.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_sparsecone

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Choosing the right colormap is important. A bad colormap like ``jet`` (standard in ROOT and mat...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_colourmap_pitfalls_thumb.png

        :ref:`sphx_glr_auto_examples_plot_colourmap_pitfalls.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_colourmap_pitfalls

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Plot the PMT directions for a given DOM.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_pmt_directions_thumb.png

        :ref:`sphx_glr_auto_examples_plot_pmt_directions.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_pmt_directions

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Convex hull of a set of points, representing Dom x-y positions.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_convex_hull_thumb.png

        :ref:`sphx_glr_auto_examples_plot_convex_hull.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_convex_hull

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Estimate track/DOM distances using the number of hits per DOM. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_dom_hits_thumb.png

        :ref:`sphx_glr_auto_examples_plot_dom_hits.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_dom_hits

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_basic_analysis_thumb.png

        :ref:`sphx_glr_auto_examples_plot_basic_analysis.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_basic_analysis
.. raw:: html

    <div style='clear:both'></div>

.. _batch_examples:

Batch Stuff
-----------

Scripts to show how to solve problems using the batch farm (SGE) e.g. in Lyon.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Apply the ROyPrefit to a set of files.">

.. only:: html

    .. figure:: /auto_examples/batch/images/thumb/sphx_glr_qprefit_thumb.png

        :ref:`sphx_glr_auto_examples_batch_qprefit.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/batch/qprefit

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Convert ROOT files to HDF5 on the SGE.">

.. only:: html

    .. figure:: /auto_examples/batch/images/thumb/sphx_glr_qtohdf5_thumb.png

        :ref:`sphx_glr_auto_examples_batch_qtohdf5.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/batch/qtohdf5
.. raw:: html

    <div style='clear:both'></div>

.. _monitoring_examples:

Monitoring
----------------

Scripts used to monitor the detector and servers.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This application demonstrates how to access MSGs from Ligier.">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_msg_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_msg.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/msg

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This application demonstrates how to access monitoring channel data.">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_io_monit_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_io_monit.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/io_monit

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Subscribes to given tag(s) and sends them to another Ligier. This script is also available as a...">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_ligier_mirror_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_ligier_mirror.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/ligier_mirror

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The following script calculates the PMT time offsets using K40 coincidences">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_k40_calibration_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_k40_calibration.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/k40_calibration

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The following script calculates the mean PMT rates and updates the plot.">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_pmt_rates_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_pmt_rates.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/pmt_rates

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The following script checks the high-rate-veto for each PMT.">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_hrv_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_hrv.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/hrv

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This script picks a monitoring channel packet with no HRV flags for any PMT and tries to match ...">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_tmch_sum_offsets_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_tmch_sum_offsets.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/tmch_sum_offsets

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A (messy) script to monitor the trigger rates.">

.. only:: html

    .. figure:: /auto_examples/monitoring/images/thumb/sphx_glr_trigger_rates_thumb.png

        :ref:`sphx_glr_auto_examples_monitoring_trigger_rates.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/monitoring/trigger_rates
.. raw:: html

    <div style='clear:both'></div>

.. _network_examples:

Network
----------------

A collection of network related stuff.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A simple UDP forwarder for ControlHost messages.">

.. only:: html

    .. figure:: /auto_examples/network/images/thumb/sphx_glr_udp_dispatcher_thumb.png

        :ref:`sphx_glr_auto_examples_network_udp_dispatcher.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/network/udp_dispatcher

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A module to send live log messages to a log.io server. ">

.. only:: html

    .. figure:: /auto_examples/network/images/thumb/sphx_glr_logio_thumb.png

        :ref:`sphx_glr_auto_examples_network_logio.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/network/logio
.. raw:: html

    <div style='clear:both'></div>

Miscellaneous
-------------


.. raw:: html

    <div style='clear:both'></div>

.. _offline_examples:

Offline Analysis
----------------

Scripts to show how to access and analyse offline data.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to read and parse EVT files, which are used in our Monte Carlo productio...">

.. only:: html

    .. figure:: /auto_examples/offline_analysis/images/thumb/sphx_glr_plot_evt_readout_thumb.png

        :ref:`sphx_glr_auto_examples_offline_analysis_plot_evt_readout.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/offline_analysis/plot_evt_readout

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Combine k40calib results into a single CSV file.">

.. only:: html

    .. figure:: /auto_examples/offline_analysis/images/thumb/sphx_glr_k40summary_thumb.png

        :ref:`sphx_glr_auto_examples_offline_analysis_k40summary.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/offline_analysis/k40summary

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Shows the median trigger contribution for each DOM. This script can be used to easily identify ...">

.. only:: html

    .. figure:: /auto_examples/offline_analysis/images/thumb/sphx_glr_trigger_contribution_thumb.png

        :ref:`sphx_glr_auto_examples_offline_analysis_trigger_contribution.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/offline_analysis/trigger_contribution

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Standalone job submitter for K40 offline calibrations with KM3Pipe.">

.. only:: html

    .. figure:: /auto_examples/offline_analysis/images/thumb/sphx_glr_qk40calib_thumb.png

        :ref:`sphx_glr_auto_examples_offline_analysis_qk40calib.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/offline_analysis/qk40calib

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This script creates a histogram to show the trigger contribution for events.">

.. only:: html

    .. figure:: /auto_examples/offline_analysis/images/thumb/sphx_glr_trigger_map_thumb.png

        :ref:`sphx_glr_auto_examples_offline_analysis_trigger_map.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/offline_analysis/trigger_map
.. raw:: html

    <div style='clear:both'></div>

.. _realtime_examples:

Realtime Analysis
-------------------

Scripts to show how to access and analyse live data from the detector.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Recieves triggered events from the detector and dumps them to a file.">

.. only:: html

    .. figure:: /auto_examples/realtime_analysis/images/thumb/sphx_glr_event_dumper_thumb.png

        :ref:`sphx_glr_auto_examples_realtime_analysis_event_dumper.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/realtime_analysis/event_dumper
.. raw:: html

    <div style='clear:both'></div>

.. _stats:

Statistics
----------

Examples showing how to fit distributions etc



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Load a histogram from a file, plot it, draw random samples. ">

.. only:: html

    .. figure:: /auto_examples/stats/images/thumb/sphx_glr_plot_histograms_thumb.png

        :ref:`sphx_glr_auto_examples_stats_plot_histograms.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/stats/plot_histograms

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Try to reproduce the analysis in `Cosma Shalizi&#x27;s blogpost &lt;http://bactra.org/weblog/857.html&gt;`...">

.. only:: html

    .. figure:: /auto_examples/stats/images/thumb/sphx_glr_plot_serial_killer_thumb.png

        :ref:`sphx_glr_auto_examples_stats_plot_serial_killer.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/stats/plot_serial_killer

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Histograms, PDF fits, Kernel Density. ">

.. only:: html

    .. figure:: /auto_examples/stats/images/thumb/sphx_glr_plot_fitting_dists_thumb.png

        :ref:`sphx_glr_auto_examples_stats_plot_fitting_dists.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/stats/plot_fitting_dists

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Fit several distributions to angular residuals.">

.. only:: html

    .. figure:: /auto_examples/stats/images/thumb/sphx_glr_guess_the_dist_thumb.png

        :ref:`sphx_glr_auto_examples_stats_guess_the_dist.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/stats/guess_the_dist
.. raw:: html

    <div style='clear:both'></div>

.. _unsorted_examples:

Unsorted
--------

Unsorted stuff.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Seatray has a builtint HDF5 writer. This is how to read the file. ">

.. only:: html

    .. figure:: /auto_examples/unsorted/images/thumb/sphx_glr_h5_ant_thumb.png

        :ref:`sphx_glr_auto_examples_unsorted_h5_ant.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/unsorted/h5_ant

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="">

.. only:: html

    .. figure:: /auto_examples/unsorted/images/thumb/sphx_glr_elog-slack_thumb.png

        :ref:`sphx_glr_auto_examples_unsorted_elog-slack.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/unsorted/elog-slack
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//Users/tamasgal/Dev/km3pipe/doc/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//Users/tamasgal/Dev/km3pipe/doc/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
